@@ -66,12 +66,11 @@ class Manager:
     Arguments:
       cls: A class derived from the ``logging.logger`` class.
     """
-    logging.getLogger().__class__ = cls
     logging.setLoggerClass(cls)
 
   def _set_vault(self, vault):
     """Set the ``laboro.vault.Vault`` instance for the logger."""
-    logging.getLogger().set_vault(vault)
+    logging.getLogger("laboro.main").set_vault(vault)
 
   def set_log_level(self, level):
     """Set the log level
@@ -82,7 +81,7 @@ class Manager:
     Raises:
       ``ValueError``: When the given ``level`` is not a valid level name.
     """
-    logging.getLogger().setLevel(level)
+    logging.getLogger("laboro.main").setLevel(level)
 
   def add_file_handler(self, logdir, workflow, session):
     """Adds a file handler to the logger.
@@ -101,7 +100,7 @@ class Manager:
                                      datefmt=self.datefmt,
                                      level_styles=self.f_level_styles,
                                      field_styles=self.f_field_styles))
-    logging.getLogger().addHandler(self.handlers[session])
+    logging.getLogger("laboro.main").addHandler(self.handlers[session])
 
   def remove_file_handler(self, session):
     """Removes the file handler associated with the specified session.
@@ -109,7 +108,7 @@ class Manager:
     Arguments:
       session: A unique string specifying a workflow session.
     """
-    logging.getLogger().removeHandler(self.handlers[session])
+    logging.getLogger("laboro.main").removeHandler(self.handlers[session])
 
   @staticmethod
   def print_logfile(logdir, workflow, session):
