@@ -119,6 +119,24 @@ class Validator:
         logging.critical(f"[{msg['type']}] {msg['message']}")
         raise LaboroError(f"[{msg['type']}] {msg['message']}")
 
+  def set_default_obj_args(self, specification, args):
+    obj = self._load_file(specification)
+    return self._set_default_args(obj, args)
+
+  def set_default_method_args(self, method, args):
+    return self._set_default_args(method, args)
+
+  def _set_default_args(self, obj, args):
+    if obj.get("args") is not None:
+      default_args = obj.get("args").copy()
+      for arg in default_args:
+        if arg.get("default") is not None:
+          arg["value"] = arg["default"]
+        if args.get(arg["name"]) is not None:
+          arg["value"] = args.get(arg["name"])
+      return {arg["name"]: arg["value"] for arg in default_args if arg.get("value") is not None}
+    return args
+
   def _load_file(self, filepath):
     try:
       with open(filepath, mode="r", encoding="utf-8") as schema:
