@@ -65,7 +65,7 @@ class Method:
     for item in self.iterable:
       self.ctx.store.method_item = item
       if self.runnable:
-        logging.getLogger().log_section("METHOD",
+        logging.getLogger("laboro.main").log_section("METHOD",
                                         f"{self.name}")
         method_args = self._get_method_args()
         self.ctx.register_method_secrets(self.instance,
@@ -81,4 +81,4 @@ class Method:
             self.ctx.put(self.output, result)
       else:
         msg = f"Skipping  {self.name}: Condition not met: {self.when}"
-        logging.getLogger().log_section("METHOD", msg, level=logging.WARNING)
+        logging.getLogger("laboro.main").log_section("METHOD", msg, level=logging.WARNING)
